pub struct ScheduleOptions { /* private fields */ }Expand description
Optional settings for DurableEngine::create_schedule.
Implementations
Sourceimpl ScheduleOptions
impl ScheduleOptions
Sourcepub fn context<T: Serialize>(self, ctx: &T) -> Self
pub fn context<T: Serialize>(self, ctx: &T) -> Self
Attach a user value passed along with the schedule.
Sourcepub fn automatic_backfill(self, on: bool) -> Self
pub fn automatic_backfill(self, on: bool) -> Self
Backfill missed ticks when the schedule is (re)installed after downtime.
Sourcepub fn cron_timezone(self, tz: impl Into<String>) -> Self
pub fn cron_timezone(self, tz: impl Into<String>) -> Self
Interpret the cron spec in this IANA timezone instead of UTC.
Sourcepub fn queue_name(self, name: impl Into<String>) -> Self
pub fn queue_name(self, name: impl Into<String>) -> Self
Route each tick to the named queue instead of running it directly.